@@ -59,6 +59,15 @@ class Index:
     @property
     def is_monotonic_increasing(self) -> bool:
         """Check whether the index is sorted in ascending order."""
+        return self._is_monotonic("__ge__")
+
+    @property
+    def is_monotonic_decreasing(self) -> bool:
+        """Check whether the index is sorted in descending order."""
+        return self._is_monotonic("__le__")
+
+    def _is_monotonic(self, op: str) -> bool:
+        """Check whether the index is sorted."""
         index = self._parent._index
         columns = self._parent._columns
         last_level = len(index) - 1
@@ -67,7 +76,7 @@ class Index:
             values = columns[level]
             if mask is not None:
                 values = values[mask]
-            if (values[1:] >= values[:-1]).all():
+            if getattr(values[1:], op)(values[:-1]).all():
                 if i == last_level or len(values) == 1:
                     return True
                 if mask is None:
@@ -457,6 +466,33 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
         df._index = self._index
         return df
 
+    def sample(
+        self,
+        n: int | None = None,
+        frac: float | int | None = None,
+        replace: bool = False,
+        weights: npt.NDArray[np.float_] | None = None,
+        ignore_index: bool = False,
+    ):
+        """
+        Return a random sample of rows in a new DataFrame.
+
+        :param n: Number of rows to sample. Cannot be passed together with `frac`.
+        :param frac: Ratio of rows to sample. 1 == length. Cannot be passed together with `n`.
+        :param replace: Sample with replacement.
+        :param weights: The probabilities associated with each row.
+        :param ignore_index: Reset the index in the sampled DataFrame.
+        """
+        if (frac is None) == (n is None):
+            raise ValueError("Must define one and only one of `n` and `frac`")
+        if frac is not None:
+            n = int(len(self) * frac)
+        indexes = np.random.choice(np.arange(len(self), dtype=int), n, replace=replace, p=weights)
+        df = self.take(indexes)
+        if ignore_index:
+            df.reset_index(inplace=True)
+        return df
+
     def astype(
         self,
         dtype: np.dtype | str | type | Mapping[Hashable, np.dtype | str | type],
